import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format,
} from 'd3';

const sectionColors = [
  'olive',
  'teal',
  'Pink',
  'coral',
  'Grey',
  'yellow',
  'orange',
  'wheat',
  'lightgreen',
  'aqua',
  'seagreen',
]; // representation of states in different colors
// from github dataset Url made raw
const csvUrl =
  'https://gist.githubusercontent.com/samithapatlolla/2703b84e9a79a86ce98d0ce79466ad29/raw/6dbea83a62622b6b1076c734e6c548cd1c22d8c4/fishexport.csv';
//fetching data from dataset
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

const xAxisTickFormat = (number) => format('.4~g')(number);

const render = (data, total) => {
  const pieData = pie().value((d) => d.year2007)(data);
  const colors = scaleOrdinal()
    .domain(data)
    .range(sectionColors);

  const arcGenerator = d3
    .arc()
    .innerRadius(0)
    .outerRadius(250);

  //arc
  const segments = arc()
    .innerRadius(0)
    .outerRadius(175)
    .padAngle(0)
    .padRadius(0);

  const sections = svg
    .append('g')
    .attr('transform', `translate(250,250)`)
    .selectAll('path')
    .data(pieData);

  sections
    .enter()
    .append('path')
    .attr('d', segments)
    .attr('fill', (d) => colors(d.data.Land_Area));
  //section label
  sections
    .enter()
    .append('text')
    .text(
      (d) => xAxisTickFormat(d.data.year2007 / 1000) + 'K',
    )
    .attr('transform', function (d) {
      return 'translate(' + arcGenerator.centroid(d) + ')';
    })
    .style('text-anchor', 'middle')
    .style('fill', 'black')
    .style('font-size', 15);
  //legends
  const legends = svg
    .append('g')
    .attr('transform', 'translate(500,100)')
    .selectAll('.legends')
    .data(pieData);

  const legend = legends
    .enter()
    .append('g')
    .classed('.legends', true)
    .attr('transform', (d, i) => {
      return `translate(0,${(i + 1) * 30})`;
    });

  legend
    .append('rect')
    .attr('width', 20)
    .attr('height', 20)
    .attr('fill', (d) => colors(d.data.year2007));
  legend
    .append('text')
    .attr('x', 25)
    .attr('y', 15)
    .attr('class', 'legend_text')
    .text((d) => d.data.Land_Area);
  legend
    .append('text')
    .attr('x', 250)
    .attr('y', 15)
    .attr('class', 'legend_value')
    .text(
      (d) => xAxisTickFormat(d.data.year2007) + 'Inches',
    );
};

const run = async () => {
  let data = await fetchData();
  let total = 0;
  data.forEach((d) => {
    d.year2007 = +d.year2007;
    total += d.year2007;
  });
  render(data, total);
};
run();
